# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: premium_marketing/v1/PremiumMarketingComponentProperties.proto
# Protobuf Python Version: 5.28.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    3,
    '',
    'premium_marketing/v1/PremiumMarketingComponentProperties.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>premium_marketing/v1/PremiumMarketingComponentProperties.proto\x12#discord_protos.premium_marketing.v1\"\xf0\xaa\x02\n#PremiumMarketingComponentProperties\x12\x1a\n\x12\x63ontent_identifier\x18\x03 \x01(\t\x12\x15\n\x0bplaceholder\x18\x01 \x01(\tH\x00\x12\x94\x01\n\x1c\x61nnouncement_modal_variant_1\x18\x02 \x01(\x0b\x32l.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.AnnouncementModalVariant1PropertiesH\x00\x12j\n\x0bpremium_tab\x18\x04 \x01(\x0b\x32S.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PremiumTabH\x00\x12}\n\x15marketing_page_banner\x18\x05 \x01(\x0b\x32\\.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MarketingPageBannerH\x00\x12{\n\x14payment_modal_banner\x18\x06 \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PaymentModalBannerH\x00\x12y\n\x13mobile_bottom_sheet\x18\x07 \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MobileBottomSheetH\x00\x12\x66\n\tgift_icon\x18\x08 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftIconH\x00\x12y\n\x13gift_icon_coachmark\x18\t \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftIconCoachmarkH\x00\x12\x8f\x01\n\x1fgift_plan_selection_card_banner\x18\n \x01(\x0b\x32\x64.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftPlanSelectionCardBannerH\x00\x12\x85\x01\n\x19gift_customization_banner\x18\x0b \x01(\x0b\x32`.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftCustomizationBannerH\x00\x12\x95\x01\n\"billing_settings_nitro_gift_banner\x18\x0c \x01(\x0b\x32g.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.BillingSettingsNitroGiftBannerH\x00\x12{\n\x14gift_reminder_nagbar\x18\r \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftReminderNagbarH\x00\x12\x81\x01\n\x17gift_reminder_coachmark\x18\x0e \x01(\x0b\x32^.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GiftReminderCoachmarkH\x00\x12y\n\x13premium_tab_tooltip\x18\x0f \x01(\x0b\x32Z.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.PremiumTabTooltipH\x00\x1am\n\x0b\x46\x65\x61tureCard\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04pill\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x12\n\nimage_link\x18\x04 \x01(\t\x12\x1e\n\x16image_link_light_theme\x18\x05 \x01(\t\x1a\x90\x01\n\x12SubscriptionButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a<\n\x08Subtitle\x12\x0c\n\x04link\x18\x01 \x01(\t\x12\x0e\n\x06locale\x18\x02 \x01(\t\x12\x12\n\nis_default\x18\x03 \x01(\x08\x1a\xff\x05\n\x0fVariant1Storage\x12\xb5\x01\n)hero_art_localized_video_links_dark_theme\x18\x01 \x03(\x0b\x32\x81\x01.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtLocalizedVideoLinksDarkThemeEntry\x12\xb7\x01\n*hero_art_localized_video_links_light_theme\x18\x02 \x03(\x0b\x32\x82\x01.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtLocalizedVideoLinksLightThemeEntry\x12\x9e\x01\n\x1dhero_art_video_subtitle_links\x18\x03 \x03(\x0b\x32w.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1Storage.HeroArtVideoSubtitleLinksEntry\x1aJ\n(HeroArtLocalizedVideoLinksDarkThemeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1aK\n)HeroArtLocalizedVideoLinksLightThemeEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a@\n\x1eHeroArtVideoSubtitleLinksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x85\x06\n#AnnouncementModalVariant1Properties\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x11\n\tsubheader\x18\x02 \x01(\t\x12\x12\n\nvideo_link\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12k\n\rfeature_cards\x18\x05 \x03(\x0b\x32T.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.FeatureCard\x12p\n\x06\x62utton\x18\x06 \x01(\x0b\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.SubscriptionButtonH\x00\x88\x01\x01\x12\x13\n\x0b\x64ismiss_key\x18\x07 \x01(\t\x12\'\n\x1fhero_art_video_link_light_theme\x18\x08 \x01(\t\x12&\n\x1ehero_art_image_link_dark_theme\x18\t \x01(\t\x12\'\n\x1fhero_art_image_link_light_theme\x18\n \x01(\t\x12\x16\n\x0emodal_top_pill\x18\x0b \x01(\t\x12\x0c\n\x04\x62ody\x18\x0c \x01(\t\x12s\n\x18hero_art_video_subtitles\x18\r \x03(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Subtitle\x12n\n\x07storage\x18\x0e \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.Variant1StorageH\x01\x88\x01\x01\x42\t\n\x07_buttonB\n\n\x08_storage\x1a\x43\n\nPremiumTab\x12\x13\n\x0b\x62\x61\x64ge_label\x18\x01 \x01(\t\x12 \n\x18\x61\x63knowledged_badge_label\x18\x02 \x01(\t\x1a\x97\x01\n\x19MarketingPageBannerButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a\xe3\x01\n\x13MarketingPageBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12w\n\x06\x62utton\x18\x05 \x01(\x0b\x32\x62.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.MarketingPageBannerButtonH\x00\x88\x01\x01\x42\t\n\x07_button\x1a\x45\n\x12PaymentModalBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x1a\x87\x01\n\tCTAButton\x12\x0c\n\x04\x63opy\x18\x01 \x01(\t\x12l\n\rbutton_action\x18\x02 \x01(\x0e\x32U.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ButtonAction\x1a\xcb\x02\n\x11MobileBottomSheet\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x17\n\x0fhelp_article_id\x18\x04 \x01(\t\x12g\n\x06\x62utton\x18\x05 \x01(\x0b\x32R.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.CTAButtonH\x00\x88\x01\x01\x12x\n\x13\x64ismissible_content\x18\x06 \x01(\x0e\x32[.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.DismissibleContentB\t\n\x07_button\x1a-\n\x08Gradient\x12\x12\n\x06\x63olors\x18\x01 \x03(\tB\x02\x10\x00\x12\r\n\x05\x61ngle\x18\x02 \x01(\x02\x1a\xdf\x01\n\x08GiftIcon\x12\x19\n\x11\x62ox_animation_url\x18\x01 \x01(\t\x12\x1d\n\x15trinket_animation_url\x18\x02 \x01(\t\x12\"\n\x1atrinket_glow_animation_url\x18\x03 \x01(\t\x12h\n\x08gradient\x18\x04 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x42\x0b\n\t_gradient\x1ai\n\x0fThemeAwareAsset\x12\x11\n\tlight_url\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61rk_url\x18\x02 \x01(\t\x12\x18\n\x10light_static_url\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x61rk_static_url\x18\x04 \x01(\t\x1a\xbc\x01\n\x11GiftIconCoachmark\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x11\n\tasset_url\x18\x03 \x01(\t\x12l\n\x05\x61sset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\x1a\xcf\x07\n\x1bGiftPlanSelectionCardBanner\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65sktop_body\x18\x02 \x01(\t\x12\x13\n\x0bmobile_body\x18\x03 \x01(\t\x12s\n\x0c\x61vatar_asset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x12\x18\n\x10\x62\x61nner_asset_url\x18\x05 \x01(\t\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x06 \x01(\t\x12\x16\n\x0e\x63\x61rd_asset_url\x18\x07 \x01(\t\x12h\n\x08gradient\x18\x08 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x01\x88\x01\x01\x12s\n\x0c\x62\x61nner_asset\x18\t \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\n \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x03\x88\x01\x01\x12q\n\ncard_asset\x18\x0b \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x04\x88\x01\x01\x12z\n\x13mobile_banner_asset\x18\x0c \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x05\x88\x01\x01\x42\x0f\n\r_avatar_assetB\x0b\n\t_gradientB\x0f\n\r_banner_assetB\x13\n\x11_background_assetB\r\n\x0b_card_assetB\x16\n\x14_mobile_banner_asset\x1a\x8e\x05\n\x17GiftCustomizationBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x65sktop_body\x18\x02 \x01(\t\x12\x13\n\x0bmobile_body\x18\x03 \x01(\t\x12h\n\x08gradient\x18\x04 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x05 \x01(\t\x12l\n\x05\x61sset\x18\x06 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x01\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\x07 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x12~\n\x17mobile_background_asset\x18\x08 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x03\x88\x01\x01\x42\x0b\n\t_gradientB\x08\n\x06_assetB\x13\n\x11_background_assetB\x1a\n\x18_mobile_background_asset\x1a\x9a\x04\n\x1e\x42illingSettingsNitroGiftBanner\x12\x11\n\tasset_url\x18\x01 \x01(\t\x12\x0e\n\x06header\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\x12\x1c\n\x14\x62\x61\x63kground_asset_url\x18\x04 \x01(\t\x12h\n\x08gradient\x18\x05 \x01(\x0b\x32Q.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.GradientH\x00\x88\x01\x01\x12\x12\n\ntext_color\x18\x06 \x01(\t\x12\x18\n\x10\x61\x64\x64itional_terms\x18\x07 \x01(\t\x12l\n\x05\x61sset\x18\x08 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x01\x88\x01\x01\x12w\n\x10\x62\x61\x63kground_asset\x18\t \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x02\x88\x01\x01\x42\x0b\n\t_gradientB\x08\n\x06_assetB\x13\n\x11_background_asset\x1a\"\n\x12GiftReminderNagbar\x12\x0c\n\x04\x62ody\x18\x01 \x01(\t\x1a\xc0\x01\n\x15GiftReminderCoachmark\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12\x11\n\tasset_url\x18\x03 \x01(\t\x12l\n\x05\x61sset\x18\x04 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\x1a\xa9\x01\n\x11PremiumTabTooltip\x12\x0e\n\x06header\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12l\n\x05\x61sset\x18\x03 \x01(\x0b\x32X.discord_protos.premium_marketing.v1.PremiumMarketingComponentProperties.ThemeAwareAssetH\x00\x88\x01\x01\x42\x08\n\x06_asset\"\xa3\x02\n\x0c\x42uttonAction\x12\x1d\n\x19\x42UTTON_ACTION_UNSPECIFIED\x10\x00\x12%\n!BUTTON_ACTION_OPEN_MARKETING_PAGE\x10\x01\x12+\n\'BUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL\x10\x02\x12+\n\'BUTTON_ACTION_OPEN_TIER_1_PAYMENT_MODAL\x10\x03\x12\x46\nBBUTTON_ACTION_OPEN_TIER_2_PAYMENT_MODAL_CUSTOM_CONFIRMATION_FOOTER\x10\x04\x12+\n\'BUTTON_ACTION_OPEN_PLAN_SELECTION_MODAL\x10\x05\"\xd9\xeb\x01\n\x12\x44ismissibleContent\x12+\n\'DISMISSIBLE_CONTENT_HUB_WAITLIST_UPSELL\x10\x00\x12\x33\n/DISMISSIBLE_CONTENT_APPLICATION_COMMAND_TOOLTIP\x10\x01\x12/\n+DISMISSIBLE_CONTENT_HUB_EVENT_HEADER_UPSELL\x10\x02\x12\x38\n4DISMISSIBLE_CONTENT_CHANNELINFO_CHANNELBANNER_NOTICE\x10\x03\x12\x34\n0DISMISSIBLE_CONTENT_ACCOUNT_MULTIACCOUNT_TOOLTIP\x10\x04\x12-\n)DISMISSIBLE_CONTENT_CHANNEL_NOTICE_INVITE\x10\x06\x12.\n*DISMISSIBLE_CONTENT_CHANNEL_NOTICE_HUBLINK\x10\x07\x12\x34\n0DISMISSIBLE_CONTENT_CHANNEL_NOTICE_QUICKSWITCHER\x10\x08\x12\x41\n=DISMISSIBLE_CONTENT_CHANNEL_NOTICE_PREMIUM_GUILD_SUBSCRIPTION\x10\t\x12\x33\n/DISMISSIBLE_CONTENT_CHANNEL_NOTICE_GUILD_BANNER\x10\x0b\x12\x31\n-DISMISSIBLE_CONTENT_GUILD_HEADER_EVENT_UPSELL\x10\x0c\x12:\n6DISMISSIBLE_CONTENT_GUILD_HEADER_ANIMATED_GUILD_BANNER\x10\x0f\x12.\n*DISMISSIBLE_CONTENT_NAGBAR_NOTICE_DOWNLOAD\x10\x10\x12\x35\n1DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_SPOTIFY\x10\x11\x12\x39\n5DISMISSIBLE_CONTENT_NAGBAR_NOTICE_CONNECT_PLAYSTATION\x10\x12\x12\x34\n0DISMISSIBLE_CONTENT_ACTIVITIES_SUNSET_COACH_MARK\x10\x14\x12\x33\n/DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_PROMO\x10\x15\x12\x43\n?DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_TWO_TRIAL_ENDING\x10\x16\x12\x38\n4DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_REACTIVATE\x10\x17\x12\x35\n1DISMISSIBLE_CONTENT_PREMIUM_5TH_ANNIVERSARY_MODAL\x10\x18\x12\x31\n-DISMISSIBLE_CONTENT_GUILD_JOIN_FEEDBACK_MODAL\x10\x19\x12=\n9DISMISSIBLE_CONTENT_VOICE_QUALITY_BOOSTING_UPSELL_TOOLTIP\x10\x1a\x12\x38\n4DISMISSIBLE_CONTENT_ACTIVITIES_EARLY_USER_COACH_MARK\x10\x1b\x12=\n9DISMISSIBLE_CONTENT_GUILD_HEADER_SERVER_DISCOVERY_TOOLTIP\x10\x1c\x12\x36\n2DISMISSIBLE_CONTENT_ACTIVITIES_TUTORIAL_COACH_MARK\x10\x1d\x12\x37\n3DISMISSIBLE_CONTENT_NAGBAR_NOTICE_LOCALIZED_PRICING\x10!\x12,\n(DISMISSIBLE_CONTENT_SOUNDBOARD_EDUCATION\x10#\x12=\n9DISMISSIBLE_CONTENT_GUILD_HEADER_ROLE_SUBSCRIPTION_UPSELL\x10%\x12\x41\n=DISMISSIBLE_CONTENT_CALL_CHAT_BUTTON_TEXT_IN_VOICE_COACH_MARK\x10&\x12\x44\n@DISMISSIBLE_CONTENT_GUILD_DISCOVERY_LANDING_PAGE_SETTINGS_UPSELL\x10\'\x12\x36\n2DISMISSIBLE_CONTENT_GUILD_INSIGHTS_ACCESS_RATE_NEW\x10(\x12\x30\n,DISMISSIBLE_CONTENT_NOW_PLAYING_CONSENT_CARD\x10)\x12J\nFDISMISSIBLE_CONTENT_GUILD_HEADER_BOOSTING_LOW_PRICE_EXPERIMENT_TOOLTIP\x10*\x12\x32\n.DISMISSIBLE_CONTENT_FORUM_CHANNEL_UPSELL_MODAL\x10,\x12=\n9DISMISSIBLE_CONTENT_POGGERMODE_BIRTHDAY_EDUCATION_TOOLTIP\x10.\x12\x33\n/DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_HALFSHEET\x10/\x12\x37\n3DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_THEMED\x10\x30\x12\x38\n4DISMISSIBLE_CONTENT_MWEB_APP_DOWNLOAD_NAGBAR_BLURPLE\x10\x31\x12+\n\'DISMISSIBLE_CONTENT_GUILD_FEED_NUX_CARD\x10\x32\x12?\n;DISMISSIBLE_CONTENT_GUILD_HEADER_FREE_STICKER_SLOTS_TOOLTIP\x10\x34\x12?\n;DISMISSIBLE_CONTENT_ACTIVITIES_NITRO_TUTORIAL_COACH_MARK_V2\x10\x35\x12=\n9DISMISSIBLE_CONTENT_ACTIVITIES_TEXT_INPUT_BUTTON_SPARKLES\x10\x37\x12-\n)DISMISSIBLE_CONTENT_GUILD_DELETE_FEEDBACK\x10\x38\x12,\n(DISMISSIBLE_CONTENT_GUILD_LEAVE_FEEDBACK\x10\x39\x12)\n%DISMISSIBLE_CONTENT_AUTH_SESSIONS_NEW\x10?\x12(\n$DISMISSIBLE_CONTENT_DONUT_MOBILE_NUX\x10\x41\x12\x44\n@DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_MWEB_PURCHASE_UPSELL\x10\x42\x12\x31\n-DISMISSIBLE_CONTENT_FORUM_CHANNEL_HELPER_CARD\x10\x43\x12.\n*DISMISSIBLE_CONTENT_PASSPORT_USER_SETTINGS\x10\x46\x12\x30\n,DISMISSIBLE_CONTENT_SUMMER_BOGO_ANNOUNCEMENT\x10G\x12\x37\n3DISMISSIBLE_CONTENT_COMMANDS_MIGRATION_UPSELL_MODAL\x10H\x12\x34\n0DISMISSIBLE_CONTENT_FILE_LIMIT_UPLOAD_COACH_MARK\x10I\x12)\n%DISMISSIBLE_CONTENT_DONUT_DESKTOP_NUX\x10M\x12<\n8DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_EMOJI_UPSELL\x10O\x12L\nHDISMISSIBLE_CONTENT_PREMIUM_SUBSCRIPTION_UPSELL_EMOJI_PICKER_TOP_OF_LIST\x10P\x12/\n+DISMISSIBLE_CONTENT_STAGE_RAISED_HAND_MOVED\x10Q\x12.\n*DISMISSIBLE_CONTENT_XBOX_ONE_WAY_RECONNECT\x10R\x12\x41\n=DISMISSIBLE_CONTENT_XBOX_VOICE_DESKTOP_SETTINGS_UPSELL_POPOUT\x10T\x12\x31\n-DISMISSIBLE_CONTENT_HUB_BACK_TO_SCHOOL_UPSELL\x10U\x12<\n8DISMISSIBLE_CONTENT_STUDENT_HUB_PRIVACY_SETTINGS_TOOLTIP\x10V\x12\x43\n?DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_VOICE_CONTROLS_TOGGLE_NUX\x10Y\x12\x39\n5DISMISSIBLE_CONTENT_PROFILE_THEMES_SETTINGS_VIEWED_V2\x10\\\x12/\n+DISMISSIBLE_CONTENT_CHANNEL_LIST_OPT_IN_NUX\x10^\x12-\n)DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_NUX\x10_\x12\x30\n,DISMISSIBLE_CONTENT_PROFILE_THEMES_NEW_BADGE\x10`\x12\x37\n3DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL\x10\x61\x12+\n\'DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NUX\x10\x62\x12/\n+DISMISSIBLE_CONTENT_RNA_CHANGELOG_HC_NOTICE\x10\x63\x12;\n7DISMISSIBLE_CONTENT_MESSAGE_REQUEST_SETTINGS_COACH_MARK\x10\x64\x12\x39\n5DISMISSIBLE_CONTENT_GUILD_AUTOMOD_DEFAULT_ON_UPSELL_2\x10\x65\x12\x32\n.DISMISSIBLE_CONTENT_GUILD_AUTOMOD_REGEX_UPSELL\x10\x66\x12\'\n#DISMISSIBLE_CONTENT_CONNECTIONS_NUX\x10l\x12\x30\n,DISMISSIBLE_CONTENT_XBOX_VOICE_SURVEY_NAGBAR\x10n\x12,\n(DISMISSIBLE_CONTENT_PS_ONE_WAY_RECONNECT\x10p\x12?\n;DISMISSIBLE_CONTENT_NITRODUCTION_STEP_PROFILE_CUSTOMIZATION\x10t\x12\x32\n.DISMISSIBLE_CONTENT_NITRODUCTION_STEP_BOOSTING\x10u\x12\x36\n2DISMISSIBLE_CONTENT_NITRODUCTION_STEP_CUSTOM_EMOJI\x10v\x12\x32\n.DISMISSIBLE_CONTENT_NEW_CRUNCHYROLL_CONNECTION\x10w\x12\x32\n.DISMISSIBLE_CONTENT_APP_DIRECTORY_UPSELL_MODAL\x10y\x12\x46\nBDISMISSIBLE_CONTENT_GUILD_HEADER_COMMUNITY_ONBOARDING_ADMIN_UPSELL\x10|\x12\x36\n2DISMISSIBLE_CONTENT_COMMUNITY_ONBOARDING_NEW_BADGE\x10}\x12\x31\n-DISMISSIBLE_CONTENT_VERIFIED_ROLES_COACH_MARK\x10\x7f\x12\x42\n=DISMISSIBLE_CONTENT_BLACK_FRIDAY_2022_BOGO_ANNOUNCEMENT_MODAL\x10\x82\x01\x12(\n#DISMISSIBLE_CONTENT_GG_ANNOUNCEMENT\x10\x84\x01\x12\x36\n1DISMISSIBLE_CONTENT_CHANNEL_BROWSER_NEW_BADGE_NUX\x10\x85\x01\x12\x36\n1DISMISSIBLE_CONTENT_CREATOR_PROMO_PAGE_COACH_MARK\x10\x86\x01\x12\x42\n=DISMISSIBLE_CONTENT_CREATOR_MONETIZATION_ONBOARDING_V2_UPSELL\x10\x88\x01\x12\x36\n1DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL\x10\x89\x01\x12@\n;DISMISSIBLE_CONTENT_NAGBAR_NOTICE_ONE_TIME_PAYMENT_PAST_DUE\x10\x8a\x01\x12\x39\n4DISMISSIBLE_CONTENT_DROPS_GO_LIVE_BANNER_NOTICE_HALO\x10\x8b\x01\x12\x42\n=DISMISSIBLE_CONTENT_DROPS_ELIGIBILITY_ENROLLMENT_TOOLTIP_HALO\x10\x8c\x01\x12<\n7DISMISSIBLE_CONTENT_DROPS_QUEST_COMPLETION_TOOLTIP_HALO\x10\x8d\x01\x12\x34\n/DISMISSIBLE_CONTENT_NAGBAR_BOUNCED_EMAIL_NOTICE\x10\x93\x01\x12?\n:DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_CHANNEL_NOTICE\x10\x97\x01\x12\x32\n-DISMISSIBLE_CONTENT_CONSOLE_PTT_DISABLE_ALERT\x10\x98\x01\x12\x37\n2DISMISSIBLE_CONTENT_ACTIVITIES_MINI_SHELF_SPARKLES\x10\x99\x01\x12\x34\n/DISMISSIBLE_CONTENT_DROPS_ENDED_INCOMPLETE_HALO\x10\x9a\x01\x12,\n\'DISMISSIBLE_CONTENT_GDM_INVITE_REMINDER\x10\x9d\x01\x12\x30\n+DISMISSIBLE_CONTENT_LINKED_ROLE_ADMIN_GUILD\x10\xa3\x01\x12<\n7DISMISSIBLE_CONTENT_NAGBAR_ACTIVATE_SERVER_SUBSCRIPTION\x10\xa4\x01\x12\x36\n1DISMISSIBLE_CONTENT_BURST_REACTION_BUTTON_SPARKLE\x10\xa5\x01\x12\x42\n=DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PREMIUM_TIER_0_TRIAL_ENDING\x10\xa6\x01\x12\x37\n2DISMISSIBLE_CONTENT_VC_TILE_ACTIVITIES_ENTRY_POINT\x10\xa7\x01\x12\x31\n,DISMISSIBLE_CONTENT_BURST_REACTION_COACHMARK\x10\xa9\x01\x12\x35\n0DISMISSIBLE_CONTENT_BURST_REACTIONS_REMOVE_MODAL\x10\xaa\x01\x12\x35\n0DISMISSIBLE_CONTENT_BURST_REACTION_NITRO_TOOLTIP\x10\xab\x01\x12\x35\n0DISMISSIBLE_CONTENT_CLIENT_THEMES_SETTINGS_BADGE\x10\xad\x01\x12\x30\n+DISMISSIBLE_CONTENT_CLIENT_THEMES_COACHMARK\x10\xae\x01\x12\x36\n1DISMISSIBLE_CONTENT_CLIENT_THEMES_SPARKLE_PREVIEW\x10\xaf\x01\x12(\n#DISMISSIBLE_CONTENT_STAGE_V2_UPSELL\x10\xb0\x01\x12\x33\n.DISMISSIBLE_CONTENT_QUEST_1_ENROLLMENT_TOOLTIP\x10\xb1\x01\x12\x33\n.DISMISSIBLE_CONTENT_QUEST_1_COMPLETION_TOOLTIP\x10\xb2\x01\x12/\n*DISMISSIBLE_CONTENT_QUEST_1_GO_LIVE_BANNER\x10\xb3\x01\x12\x31\n,DISMISSIBLE_CONTENT_QUEST_1_ENDED_INCOMPLETE\x10\xb4\x01\x12\x34\n/DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EXPERIENCE\x10\xb5\x01\x12@\n;DISMISSIBLE_CONTENT_APP_DIRECTORY_SERVER_SETUP_UPSELL_MODAL\x10\xb6\x01\x12\x46\nADISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_FILE_UPLOAD_COMPOSER_TOOLTIP\x10\xb7\x01\x12I\nDDISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_STICKER_PICKER_COMPOSER_TOOLTIP\x10\xb8\x01\x12G\nBDISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_EMOJI_PICKER_COMPOSER_TOOLTIP\x10\xb9\x01\x12=\n8DISMISSIBLE_CONTENT_PREMIUM_TUTORIAL_SERVER_MENU_TOOLTIP\x10\xba\x01\x12\x30\n+DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_DM\x10\xbd\x01\x12\x38\n3DISMISSIBLE_CONTENT_SUPER_REACTIONS_NITRO_MARKETING\x10\xbe\x01\x12>\n9DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_ANNOUNCEMENT_MODAL\x10\xbf\x01\x12/\n*DISMISSIBLE_CONTENT_CLYDE_GUILD_HEADER_NUX\x10\xc1\x01\x12+\n&DISMISSIBLE_CONTENT_CLYDE_CHAT_BAR_NUX\x10\xc2\x01\x12\x33\n.DISMISSIBLE_CONTENT_VOICE_MESSAGE_UPSELL_GUILD\x10\xc3\x01\x12\x32\n-DISMISSIBLE_CONTENT_ACTIVITY_GDM_CALL_TOOLTIP\x10\xc4\x01\x12\x34\n/DISMISSIBLE_CONTENT_ACTIVITY_GDM_ROCKET_SPARKLE\x10\xc5\x01\x12;\n6DISMISSIBLE_CONTENT_NITRO_DROP_2023_04_NITRO_TAB_BADGE\x10\xcd\x01\x12;\n6DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_IAP_UPSELL\x10\xce\x01\x12\x36\n1DISMISSIBLE_CONTENT_ACTIVITIES_MOBILE_PIP_FAB_NUX\x10\xd0\x01\x12\x37\n2DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_HEADER\x10\xd2\x01\x12\x37\n2DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_NAGBAR\x10\xd4\x01\x12\x39\n4DISMISSIBLE_CONTENT_GUILD_ONBOARDING_UPSELL_MODAL_V2\x10\xd5\x01\x12=\n8DISMISSIBLE_CONTENT_SUPER_REACTIONS_FREE_USER_FIRST_SENT\x10\xd6\x01\x12:\n5DISMISSIBLE_CONTENT_SUPER_REACTIONS_TOOLTIP_COACHMARK\x10\xd7\x01\x12-\n(DISMISSIBLE_CONTENT_NAGBAR_NOTICE_POMELO\x10\xd9\x01\x12\x43\n>DISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_NEW_INDICATOR\x10\xda\x01\x12P\nKDISMISSIBLE_CONTENT_APP_DIRECTORY_GUILD_SETTINGS_CONTEXT_MENU_NEW_INDICATOR\x10\xdb\x01\x12\x34\n/DISMISSIBLE_CONTENT_SUPER_REACTIONS_TAB_SPARKLE\x10\xdc\x01\x12M\nHDISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_1_SPARKLES\x10\xdd\x01\x12M\nHDISMISSIBLE_CONTENT_ACTIVITIES_WATCH_TOGETHER_APRIL_2023_WEEK_2_SPARKLES\x10\xde\x01\x12-\n(DISMISSIBLE_CONTENT_MJ_NEW_USER_CHAT_BAR\x10\xdf\x01\x12\x31\n,DISMISSIBLE_CONTENT_CHANNEL_NOTICE_CLYDE_NUX\x10\xe0\x01\x12\x33\n.DISMISSIBLE_CONTENT_SUPER_REACTIONS_FIRST_SENT\x10\xe3\x01\x12\x38\n3DISMISSIBLE_CONTENT_COMMUNITY_GUILD_SETTINGS_SAFETY\x10\xe4\x01\x12\x37\n2DISMISSIBLE_CONTENT_FRIEND_FINDER_FIRST_TIME_BADGE\x10\xe5\x01\x12\x34\n/DISMISSIBLE_CONTENT_SHARE_NITRO_BUTTON_SPARKLES\x10\xe6\x01\x12H\nCDISMISSIBLE_CONTENT_PREMIUM_MOBILE_TRIAL_USER_SETTINGS_AVATAR_BADGE\x10\xe7\x01\x12/\n*DISMISSIBLE_CONTENT_SOUNDBOARD_KEYBIND_TIP\x10\xe8\x01\x12\x33\n.DISMISSIBLE_CONTENT_QUEST_2_ENROLLMENT_TOOLTIP\x10\xea\x01\x12\x33\n.DISMISSIBLE_CONTENT_QUEST_2_COMPLETION_TOOLTIP\x10\xeb\x01\x12/\n*DISMISSIBLE_CONTENT_QUEST_2_GO_LIVE_BANNER\x10\xec\x01\x12\x31\n,DISMISSIBLE_CONTENT_QUEST_2_ENDED_INCOMPLETE\x10\xed\x01\x12?\n:DISMISSIBLE_CONTENT_GUILD_ROLE_SUBSCRIPTION_TIER_TEMPLATES\x10\xee\x01\x12-\n(DISMISSIBLE_CONTENT_MEDIA_CHANNEL_UPSELL\x10\xf3\x01\x12+\n&DISMISSIBLE_CONTENT_ADD_FRIENDS_WIDGET\x10\xf4\x01\x12\x32\n-DISMISSIBLE_CONTENT_YOU_TAB_AVATAR_ONBOARDING\x10\xf5\x01\x12\x34\n/DISMISSIBLE_CONTENT_YOU_TAB_ABOUT_ME_ONBOARDING\x10\xf6\x01\x12\x36\n1DISMISSIBLE_CONTENT_GUILD_HEADER_SUMMARIES_UPSELL\x10\xf7\x01\x12\x39\n4DISMISSIBLE_CONTENT_SUPER_REACTIONS_COACHMARK_MOBILE\x10\xfa\x01\x12\x45\n@DISMISSIBLE_CONTENT_SUPER_REACTIONS_SPARKLES_ACTION_SHEET_MOBILE\x10\xfb\x01\x12\x41\n<DISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_TIER_TEMPLATE_UPSELL\x10\xfc\x01\x12\x39\n4DISMISSIBLE_CONTENT_EMOJI_PICKER_FAVORITE_EMOJIS_TIP\x10\xfd\x01\x12M\nHDISMISSIBLE_CONTENT_SERVER_SUBSCRIPTION_SETTINGS_NEW_BADGE_TIER_TEMPLATE\x10\xfe\x01\x12I\nDDISMISSIBLE_CONTENT_SUPER_REACTIONS_MOBILE_FULLSCREEN_TAP_TO_DISMISS\x10\xff\x01\x12\x30\n+DISMISSIBLE_CONTENT_FAMILY_CENTER_NEW_BADGE\x10\x80\x02\x12\x31\n,DISMISSIBLE_CONTENT_CONSOLE_LOCAL_DETECT_CTA\x10\x81\x02\x12\x45\n@DISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_EDUCATION_UPSELLS_MOBILE\x10\x87\x02\x12@\n;DISMISSIBLE_CONTENT_GUEST_VOICE_INVITES_MENU_ITEM_NEW_BADGE\x10\x88\x02\x12N\nIDISMISSIBLE_CONTENT_REMIXING_ENTRYPOINT_OPEN_MEDIA_KEYBOARD_UPSELL_MOBILE\x10\x89\x02\x12:\n5DISMISSIBLE_CONTENT_GUILD_MEMBER_SAFETY_BANNER_NOTICE\x10\x8a\x02\x12\x42\n=DISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK\x10\x8f\x02\x12\x39\n4DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_PICKER_UPSELL\x10\x90\x02\x12\x34\n/DISMISSIBLE_CONTENT_CUSTOM_CALL_SOUNDS_SPARKLES\x10\x92\x02\x12\x37\n2DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_FLOATING_CTA\x10\x93\x02\x12\x34\n/DISMISSIBLE_CONTENT_SOUNDBOARD_MOBILE_NEW_BADGE\x10\x94\x02\x12H\nCDISMISSIBLE_CONTENT_PROFILE_THEMES_FEATURE_EDUCATION_TOOLTIP_TAKE_2\x10\x95\x02\x12\x37\n2DISMISSIBLE_CONTENT_VOICE_PANEL_BAD_CONNECTION_CTA\x10\x96\x02\x12@\n;DISMISSIBLE_CONTENT_PREMIUM_TRIAL_OFFER_MOBILE_ACTION_SHEET\x10\x97\x02\x12@\n;DISMISSIBLE_CONTENT_MEDIA_CHANNEL_MULTIPLE_THUMBNAIL_NOTICE\x10\x98\x02\x12;\n6DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_GO_LIVE_COACHMARK\x10\x99\x02\x12?\n:DISMISSIBLE_CONTENT_CLIPS_ONBOARDING_CLIP_BUTTON_COACHMARK\x10\x9a\x02\x12\x33\n.DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_COACHMARK\x10\x9b\x02\x12\x33\n.DISMISSIBLE_CONTENT_CUSTOM_APP_ICONS_NEW_BADGE\x10\x9c\x02\x12\x39\n4DISMISSIBLE_CONTENT_BROADCASTING_BROADCASTER_TOOLTIP\x10\x9d\x02\x12\x34\n/DISMISSIBLE_CONTENT_BROADCASTING_VIEWER_TOOLTIP\x10\x9e\x02\x12\x30\n+DISMISSIBLE_CONTENT_LAUNCH_PAD_PULL_TAB_NUX\x10\xa1\x02\x12.\n)DISMISSIBLE_CONTENT_MEMBERS_LAUNCH_UPSELL\x10\xa6\x02\x12\x34\n/DISMISSIBLE_CONTENT_SERVER_SHOP_PHANTOM_PREVIEW\x10\xa7\x02\x12\x36\n1DISMISSIBLE_CONTENT_RECURRING_CONTACT_SYNC_PROMPT\x10\xa9\x02\x12\x32\n-DISMISSIBLE_CONTENT_INVENTORY_TRY_PACKS_MODAL\x10\xae\x02\x12\x30\n+DISMISSIBLE_CONTENT_DEPRECATE_WIN32_MESSAGE\x10\xb1\x02\x12:\n5DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_COACHMARK\x10\xb2\x02\x12\x36\n1DISMISSIBLE_CONTENT_DEKSTOP_CUSTOM_APP_ICON_BADGE\x10\xb3\x02\x12\x39\n4DISMISSIBLE_CONTENT_CLYDE_AI_PERSONALITIES_NUX_MODAL\x10\xb8\x02\x12\x34\n/DISMISSIBLE_CONTENT_NUX_GUILD_CHANNEL_EXPLAINER\x10\xb9\x02\x12@\n;DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_DESKTOP\x10\xbc\x02\x12?\n:DISMISSIBLE_CONTENT_SUPER_REACTION_TOGGLE_EDUCATION_MOBILE\x10\xbd\x02\x12\x38\n3DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME_OR_REDESIGN\x10\xc5\x02\x12(\n#DISMISSIBLE_CONTENT_SEEN_OLD_DESIGN\x10\xc6\x02\x12,\n\'DISMISSIBLE_CONTENT_SEEN_LAUNCH_WELCOME\x10\xcf\x02\x12\x43\n>DISMISSIBLE_CONTENT_FAVORITE_SERVER_ADD_TO_FAVORITES_COACHMARK\x10\xd0\x02\x12K\nFDISMISSIBLE_CONTENT_INVENTORY_GUILD_SETTINGS_MODMIN_COACHMARK_ROLLBACK\x10\xd1\x02\x12@\n;DISMISSIBLE_CONTENT_FRIEND_FINDER_CONTACTS_IN_NOTIFICATIONS\x10\xd2\x02\x12\x35\n0DISMISSIBLE_CONTENT_OVERLAY_KEYBIND_NOTIFICATION\x10\xd4\x02\x12<\n7DISMISSIBLE_CONTENT_CHANNEL_LIST_V2_BROWSE_CHANNELS_NUX\x10\xd7\x02\x12.\n)DISMISSIBLE_CONTENT_HANG_STATUS_NEW_BADGE\x10\xda\x02\x12\x35\n0DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_TOOLTIP\x10\xdb\x02\x12\x37\n2DISMISSIBLE_CONTENT_VOICE_CALL_BG_PICKER_NEW_BADGE\x10\xdc\x02\x12\x31\n,DISMISSIBLE_CONTENT_SWIPE_TO_REPLY_COACHMARK\x10\xdd\x02\x12<\n7DISMISSIBLE_CONTENT_MOBILE_ACCESSIBILITY_COLOR_SETTINGS\x10\xde\x02\x12\x33\n.DISMISSIBLE_CONTENT_POLLS_CHAT_INPUT_COACHMARK\x10\xe2\x02\x12-\n(DISMISSIBLE_CONTENT_LOOTBOXES_ENTRYPOINT\x10\xe6\x02\x12.\n)DISMISSIBLE_CONTENT_TENURE_REWARD_PENDING\x10\xe8\x02\x12\x31\n,DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE\x10\xe9\x02\x12:\n5DISMISSIBLE_CONTENT_TENURE_REWARD_REDEEMABLE_CONFETTI\x10\xeb\x02\x12.\n)DISMISSIBLE_CONTENT_GAME_ONE_USER_SIGNUPS\x10\xec\x02\x12\x37\n2DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_SHY_COACHTIP\x10\xed\x02\x12<\n7DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_BOTS_BANNER\x10\xee\x02\x12\x42\n=DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_ACTIVITIES_BANNER\x10\xef\x02\x12<\n7DISMISSIBLE_CONTENT_APP_LAUNCHER_ONBOARDING_APPS_BANNER\x10\xf0\x02\x12;\n6DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_MARKETING\x10\xf1\x02\x12<\n7DISMISSIBLE_CONTENT_COLLECTIBLES_MOBILE_SHOP_HALF_SHEET\x10\xf2\x02\x12-\n(DISMISSIBLE_CONTENT_GENSHIN_USER_SIGNUPS\x10\xf3\x02\x12\x36\n1DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_BUTTON_NUX_V2\x10\xf4\x02\x12\x37\n2DISMISSIBLE_CONTENT_ACTIVITIES_CHAT_MENU_NEW_BADGE\x10\xf5\x02\x12;\n6DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_MODAL\x10\xf6\x02\x12;\n6DISMISSIBLE_CONTENT_PREMIUM_2024_APRIL_MARKETING_BADGE\x10\xf7\x02\x12=\n8DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PROGRESS_BAR_TOGGLE\x10\xf9\x02\x12;\n6DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_PREMIUM_TAB_BADGE\x10\xfc\x02\x12>\n9DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_LOFI_VIBES_COACHTIP\x10\xfe\x02\x12:\n5DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_GALAXY_COACHTIP\x10\xff\x02\x12\x43\n>DISMISSIBLE_CONTENT_CONTENT_INVENTORY_ONE_CLICK_REPLY_COACHTIP\x10\x80\x03\x12\x37\n2DISMISSIBLE_CONTENT_CHANNEL_LIST_CLAN_ADMIN_UPSELL\x10\x81\x03\x12\x35\n0DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_ADMIN_UPSELL\x10\x82\x03\x12\x39\n4DISMISSIBLE_CONTENT_MOBILE_NITRO_HOME_SETTINGS_BADGE\x10\x83\x03\x12\x30\n+DISMISSIBLE_CONTENT_BRAND_REFRESH_NEW_BADGE\x10\x84\x03\x12\x46\nADISMISSIBLE_CONTENT_BRAND_REFRESH_BLURPLE_TWILIGHT_APP_ICON_BADGE\x10\x85\x03\x12\x39\n4DISMISSIBLE_CONTENT_BRAND_REFRESH_CLIENT_THEME_BADGE\x10\x86\x03\x12:\n5DISMISSIBLE_CONTENT_APP_LAUNCHER_USER_APP_BETA_NOTICE\x10\x87\x03\x12<\n7DISMISSIBLE_CONTENT_COLLECTIBLES_PIRATES_MOBILE_BADGING\x10\x88\x03\x12\x45\n@DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_RETRO_AND_PIRATES_COACHTIP\x10\x89\x03\x12$\n\x1f\x44ISMISSIBLE_CONTENT_PRIDE_ICONS\x10\x8a\x03\x12.\n)DISMISSIBLE_CONTENT_PRIDE_ICONS_COACHMARK\x10\x8b\x03\x12\x35\n0DISMISSIBLE_CONTENT_PRIDE_ICONS_APPEARANCE_BADGE\x10\x8c\x03\x12*\n%DISMISSIBLE_CONTENT_CLAN_TAG_WAITLIST\x10\x8d\x03\x12\x34\n/DISMISSIBLE_CONTENT_GUILD_LIST_CLAN_USER_UPSELL\x10\x8e\x03\x12:\n5DISMISSIBLE_CONTENT_QUEST_HOME_FRIENDS_LIST_NEW_BADGE\x10\x8f\x03\x12<\n7DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_FLIP\x10\x90\x03\x12\x42\n=DISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_FLIP\x10\x91\x03\x12\x38\n3DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_FLIP\x10\x92\x03\x12\x43\n>DISMISSIBLE_CONTENT_WHATS_NEW_APP_STYLES_JUNE_2024_NITRO_BADGE\x10\x93\x03\x12I\nDDISMISSIBLE_CONTENT_WHATS_NEW_CUSTOM_NOTIFICATION_SOUNDS_NITRO_BADGE\x10\x94\x03\x12?\n:DISMISSIBLE_CONTENT_WHATS_NEW_REFERRAL_PROGRAM_NITRO_BADGE\x10\x95\x03\x12\x36\n1DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_FLIP\x10\x96\x03\x12\x37\n2DISMISSIBLE_CONTENT_WHATS_NEW_SERVER_PROFILE_BADGE\x10\x97\x03\x12:\n5DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ARCADE_COACHTIP\x10\x98\x03\x12\x31\n,DISMISSIBLE_CONTENT_CHECKOUT_RECOVERY_NAGBAR\x10\x99\x03\x12:\n5DISMISSIBLE_CONTENT_PREMIUM_2024_JUNE_MARKETING_MODAL\x10\x9a\x03\x12>\n9DISMISSIBLE_CONTENT_APP_LAUNCHER_GLOBAL_SEARCH_ONBOARDING\x10\x9b\x03\x12\x33\n.DISMISSIBLE_CONTENT_NEW_GAMING_DISCOVERY_NOTIF\x10\x9c\x03\x12\x34\n/DISMISSIBLE_CONTENT_NITRO_ON_PROFILE_SIDE_PANEL\x10\x9e\x03\x12G\nBDISMISSIBLE_CONTENT_MESSAGE_FORWARDING_DESKTOP_UTILITIES_NEW_BADGE\x10\x9f\x03\x12\x42\n=DISMISSIBLE_CONTENT_MESSAGE_FORWARDING_MOBILE_SHEET_NEW_BADGE\x10\xa0\x03\x12<\n7DISMISSIBLE_CONTENT_SUMMER_2024_BOGO_ANNOUNCEMENT_MODAL\x10\xa1\x03\x12\x42\n=DISMISSIBLE_CONTENT_GIFT_INVENTORY_QUESTS_MOVED_TO_QUEST_HOME\x10\xa5\x03\x12:\n5DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_ENTRY_MARKETING\x10\xa6\x03\x12\x36\n1DISMISSIBLE_CONTENT_CASH_APP_PAY_AWARENESS_NAGBAR\x10\xa7\x03\x12+\n&DISMISSIBLE_CONTENT_ICYMI_ALPHA_UPSELL\x10\xa9\x03\x12,\n\'DISMISSIBLE_CONTENT_PASSWORDLESS_UPSELL\x10\xab\x03\x12?\n:DISMISSIBLE_CONTENT_CHANNEL_LINKED_LOBBY_EDUCATION_TOOLTIP\x10\xad\x03\x12\x39\n4DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_DOJO_MARKETING\x10\xaf\x03\x12\x34\n/DISMISSIBLE_CONTENT_REVERSE_TRIAL_STREAM_POPOUT\x10\xb0\x03\x12\x36\n1DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE\x10\xb1\x03\x12\x33\n.DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_BUTTON\x10\xb2\x03\x12=\n8DISMISSIBLE_CONTENT_REVERSE_TRIAL_FIRST_IMPRESSION_MODAL\x10\xb3\x03\x12\x33\n.DISMISSIBLE_CONTENT_REVERSE_TRIAL_EMOJI_PICKER\x10\xb4\x03\x12\x33\n.DISMISSIBLE_CONTENT_REVERSE_TRIAL_ENDED_UPSELL\x10\xb5\x03\x12O\nJDISMISSIBLE_CONTENT_VOICE_PANEL_ACTIVITIES_SHAPES_BUTTON_EDUCATION_TOOLTIP\x10\xb7\x03\x12:\n5DISMISSIBLE_CONTENT_FOR_LATER_NOTIFICATIONS_COACHMARK\x10\xb8\x03\x12>\n9DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_THE_VAULT_MARKETING\x10\xb9\x03\x12.\n)DISMISSIBLE_CONTENT_USER_DM_MUTE_FEEDBACK\x10\xba\x03\x12\x35\n0DISMISSIBLE_CONTENT_RAPIDASH_M3_DISCOVERY_UPSELL\x10\xbb\x03\x12\x36\n1DISMISSIBLE_CONTENT_WHATS_NEW_TENURE_BADGE_REWARD\x10\xbc\x03\x12\x33\n.DISMISSIBLE_CONTENT_FOR_LATER_POPOUT_COACHMARK\x10\xbd\x03\x12\x38\n3DISMISSIBLE_CONTENT_GLOBAL_DISCOVERY_RAPIDASH_NOTIF\x10\xc0\x03\x12\x39\n4DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_BAND_MARKETING\x10\xc1\x03\x12\x34\n/DISMISSIBLE_CONTENT_RAPIDASH_MORE_GUILDS_UPSELL\x10\xc4\x03\x12\x35\n0DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_INITIAL_UPSELL\x10\xc5\x03\x12=\n8DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MOBILE_SETTINGS_NOTICE\x10\xc6\x03\x12\x33\n.DISMISSIBLE_CONTENT_RAPIDASH_RTC_BROWSE_GUILDS\x10\xc8\x03\x12;\n6DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_MARKETING_PAGE_BADGE\x10\xc9\x03\x12\x43\n>DISMISSIBLE_CONTENT_USER_PROFILE_PREMIUM_AND_SHOP_ENTRY_POINTS\x10\xca\x03\x12\x34\n/DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_DESKTOP_MODAL\x10\xce\x03\x12/\n*DISMISSIBLE_CONTENT_GIFTING_PROMOTION_ICON\x10\xd3\x03\x12G\nBDISMISSIBLE_CONTENT_GIFTING_PROMOTION_DESKTOP_FIRST_TIME_COACHMARK\x10\xd4\x03\x12\x46\nADISMISSIBLE_CONTENT_GIFTING_PROMOTION_MOBILE_FIRST_TIME_HALFSHEET\x10\xd5\x03\x12\x33\n.DISMISSIBLE_CONTENT_GIFTING_PROMOTION_REMINDER\x10\xd6\x03\x12\x34\n/DISMISSIBLE_CONTENT_CONSUMABLE_HD_POTION_UPSELL\x10\xd7\x03\x12\x39\n4DISMISSIBLE_CONTENT_HD_STREAMING_POTION_MODAL_UPSELL\x10\xd8\x03\x12\x33\n.DISMISSIBLE_CONTENT_HD_STREAMING_POTION_BANNER\x10\xd9\x03\x12\x39\n4DISMISSIBLE_CONTENT_GIFTING_INTENT_FRIENDS_TAB_BADGE\x10\xda\x03\x12<\n7DISMISSIBLE_CONTENT_FRACTIONAL_NITRO_DURATION_LEFT_PILL\x10\xdc\x03\x12;\n6DISMISSIBLE_CONTENT_RESTRICTED_ACCOUNTS_SETTING_NOTICE\x10\xdf\x03\x12\x38\n3DISMISSIBLE_CONTENT_CONNECTIONS_XBOX_LINK_COACHMARK\x10\xe0\x03\x12:\n5DISMISSIBLE_CONTENT_CONNECTIONS_NEW_CONSOLE_COACHMARK\x10\xe1\x03\x12?\n:DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_NITRO_HOME_BADGE\x10\xe2\x03\x12,\n\'DISMISSIBLE_CONTENT_SOUNDMOJI_COACHMARK\x10\xe3\x03\x12(\n#DISMISSIBLE_CONTENT_SOUNDMOJI_BADGE\x10\xe4\x03\x12?\n:DISMISSIBLE_CONTENT_REFERRAL_TRIAL_MOBILE_SENDER_COACHMARK\x10\xe5\x03\x12/\n*DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_BUTTON\x10\xe6\x03\x12/\n*DISMISSIBLE_CONTENT_TRIAL_NUX_EMOJI_PICKER\x10\xe7\x03\x12\x34\n/DISMISSIBLE_CONTENT_TRIAL_NUX_STREAM_COACH_MARK\x10\xe8\x03\x12\x36\n1DISMISSIBLE_CONTENT_TIERED_TENURE_BADGE_COACHMARK\x10\xeb\x03\x12G\nBDISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_ONBOARDING_ANNOUNCEMENT_MODAL\x10\xec\x03\x12/\n*DISMISSIBLE_CONTENT_CONFETTI_POTION_UPSELL\x10\xee\x03\x12\x34\n/DISMISSIBLE_CONTENT_SHARE_ACTIVITY_COACHMARK_V2\x10\xf0\x03\x12\x38\n3DISMISSIBLE_CONTENT_VOICE_FILTER_LOOPBACK_COACHMARK\x10\xf1\x03\x12\x36\n1DISMISSIBLE_CONTENT_VOICE_FILTER_LAUNCH_COACHMARK\x10\xf2\x03\x12\x37\n2DISMISSIBLE_CONTENT_VOICE_FILTER_IN_CALL_COACHMARK\x10\xf3\x03\x12\x39\n4DISMISSIBLE_CONTENT_REVERSE_TRIAL_NITRO_TAB_BADGE_V2\x10\xf4\x03\x12\x30\n+DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_NUX\x10\xf5\x03\x12?\n:DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_SWITCH_FROM_IP_NUX\x10\xf6\x03\x12;\n6DISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_NUX\x10\xf7\x03\x12J\nEDISMISSIBLE_CONTENT_OVERLAY_OOP_WELCOME_BACKGROUND_SWITCH_FROM_IP_NUX\x10\xf8\x03\x12\x31\n,DISMISSIBLE_CONTENT_OVERLAY_OOP_SETTINGS_NUX\x10\xf9\x03\x12.\n)DISMISSIBLE_CONTENT_Q1_2025_REVERSE_TRIAL\x10\xfa\x03\x12>\n9DISMISSIBLE_CONTENT_Q1_2025_FOLLOW_UP_REVERSE_TRIAL_OFFER\x10\xfb\x03\x12\x42\n=DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_COACHMARK\x10\xfc\x03\x12\x37\n2DISMISSIBLE_CONTENT_SWIPE_TO_MEMBER_LIST_COACHMARK\x10\x80\x04\x12H\nCDISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_ONBOARDING_COACHMARK\x10\x81\x04\x12\x43\n>DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_SHOP_ONBOARDING_COACHMARK\x10\x82\x04\x12*\n%DISMISSIBLE_CONTENT_CLICKER_COACHMARK\x10\x83\x04\x12?\n:DISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_MENU_NEW_BADGE\x10\x84\x04\x12G\nBDISMISSIBLE_CONTENT_RECENT_AVATARS_SETTINGS_PROFILE_PAGE_NEW_BADGE\x10\x85\x04\x12\x37\n2DISMISSIBLE_CONTENT_PERMADECOS_NITRO_TAB_NEW_BADGE\x10\x86\x04\x12=\n8DISMISSIBLE_CONTENT_PERMADECOS_NITRO_HOME_CARD_NEW_BADGE\x10\x88\x04\x12\x32\n-DISMISSIBLE_CONTENT_RING_USER_TO_VC_NEW_BADGE\x10\x8a\x04\x12\x39\n4DISMISSIBLE_CONTENT_DESKTOP_REFRESH_ONBOARDING_MODAL\x10\x8d\x04\x12\x33\n.DISMISSIBLE_CONTENT_GUILD_POWERUP_NOTIFICATION\x10\x91\x04\x12\x36\n1DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK\x10\x92\x04\x12\x36\n1DISMISSIBLE_CONTENT_GUILD_POWERUP_PERKS_COACHMARK\x10\x93\x04\x12:\n5DISMISSIBLE_CONTENT_THIRD_PARTY_OUTBOUND_PROMO_NAGBAR\x10\x94\x04\x12\x39\n4DISMISSIBLE_CONTENT_GUILD_TAG_USER_PROFILE_NEW_BADGE\x10\x96\x04\x12<\n7DISMISSIBLE_CONTENT_GUILD_TAG_SERVER_SETTINGS_NEW_BADGE\x10\x97\x04\x12=\n8DISMISSIBLE_CONTENT_GUILD_SETTINGS_ROLE_STYLES_NEW_BADGE\x10\x98\x04\x12;\n6DISMISSIBLE_CONTENT_NAGBAR_NOTICE_IGNORE_USER_FEEDBACK\x10\x99\x04\x12\x34\n/DISMISSIBLE_CONTENT_REPORT_TO_MOD_SURVEY_NOTICE\x10\x9a\x04\x12\x44\n?DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_NITRO_TAB_BADGE_V2\x10\x9b\x04\x12H\nCDISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FIRST_IMPRESSION_MODAL\x10\x9c\x04\x12\x41\n<DISMISSIBLE_CONTENT_Q2_2025_MARKETING_MOMENT_FOLLOW_UP_MODAL\x10\x9d\x04\x12.\n)DISMISSIBLE_CONTENT_REPORT_TO_MOD_NEW_TAG\x10\x9e\x04\x12\x34\n/DISMISSIBLE_CONTENT_NITRO_TENURE_BADGE_LEVEL_UP\x10\xa0\x04\x12\x34\n/DISMISSIBLE_CONTENT_ROBLOX_CONNECTION_COACHMARK\x10\xa1\x04\x12\x39\n4DISMISSIBLE_CONTENT_VOICE_FILTER_FIRST_USE_COACHMARK\x10\xa2\x04\x12>\n9DISMISSIBLE_CONTENT_CHANNEL_REORDER_MODAL_DISMISS_SETTING\x10\xa3\x04\x12/\n*DISMISSIBLE_CONTENT_CUSTOM_THEME_COACHMARK\x10\xa4\x04\x12<\n7DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_COACHMARK\x10\xa5\x04\x12\x44\n?DISMISSIBLE_CONTENT_VOICE_FILTER_EARLY_ACCESS_PREMIUM_TAB_BADGE\x10\xa6\x04\x12\x44\n?DISMISSIBLE_CONTENT_CLIENT_THEMES_APPEARANCE_SETTINGS_NEW_BADGE\x10\xa7\x04\x12:\n5DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_NEW_BADGE\x10\xa8\x04\x12;\n6DISMISSIBLE_CONTENT_MOBILE_BOGO_PROMOTION_ACTION_SHEET\x10\xa9\x04\x12\x39\n4DISMISSIBLE_CONTENT_CUSTOM_THEME_ENTRYPOINT_GRADIENT\x10\xaa\x04\x12\x39\n4DISMISSIBLE_CONTENT_TIERLESS_BOOSTING_SYSTEM_MESSAGE\x10\xab\x04\x12>\n9DISMISSIBLE_CONTENT_GOOGLE_PLAY_PRICE_CHANGE_ACTION_SHEET\x10\xac\x04\x12\x39\n4DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_NITRO_TAB_BADGE\x10\xad\x04\x12\x38\n3DISMISSIBLE_CONTENT_ACTIVITIES_VOICE_LAUNCHER_BADGE\x10\xae\x04\x12\x32\n-DISMISSIBLE_CONTENT_BOGO_2025_NITRO_TAB_BADGE\x10\xaf\x04\x12\x35\n0DISMISSIBLE_CONTENT_BOGO_2025_ANNOUNCEMENT_MODAL\x10\xb0\x04\x12\x36\n1DISMISSIBLE_CONTENT_NITRO_PRIVATE_BROWSING_SURVEY\x10\xb3\x04\x12\x43\n>DISMISSIBLE_CONTENT_GUILD_POWERUP_NEW_PERK_AVAILABLE_COACHMARK\x10\xb4\x04\x12?\n:DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_EDUCATIONAL_POPOVER\x10\xb5\x04\x12<\n7DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_CLOSE\x10\xb6\x04\x12\x42\n=DISMISSIBLE_CONTENT_AGE_VERIFICATION_SURVEY_MODAL_GET_STARTED\x10\xb7\x04\x12\x44\n?DISMISSIBLE_CONTENT_GUILD_PIN_PERMISSION_MIGRATION_NOTIFICATION\x10\xb8\x04\x12\x41\n<DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_NOTIFICATION\x10\xb9\x04\x12:\n5DISMISSIBLE_CONTENT_VANITY_URL_POWERUP_ROLLBACK_MODAL\x10\xba\x04\x12\x44\n?DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_DISCOVERY_REHEAT_COACHMARK\x10\xbb\x04\x12\x36\n1DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_COACHMARK\x10\xbc\x04\x12\x36\n1DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE\x10\xbd\x04\x12\x35\n0DISMISSIBLE_CONTENT_NAGBAR_NOTICE_OFFER_EXPIRING\x10\xbe\x04\x12<\n7DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_FILTER_NEW_BADGE\x10\xbf\x04\x12?\n:DISMISSIBLE_CONTENT_SEARCH_AUTHOR_TYPE_SEARCH_RESULTS_HINT\x10\xc0\x04\x12\x31\n,DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER\x10\xc1\x04\x12\x43\n>DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NEW_BADGE_PROFILE_PAGE\x10\xc3\x04\x12-\n(DISMISSIBLE_CONTENT_CLOUD_PLAY_NEW_BADGE\x10\xc4\x04\x12\x43\n>DISMISSIBLE_CONTENT_ACCESSIBILITY_HIGH_CONTRAST_MODE_NEW_BADGE\x10\xc7\x04\x12\x35\n0DISMISSIBLE_CONTENT_WIDGETS_RTC_UPSELL_COACHMARK\x10\xc8\x04\x12+\n&DISMISSIBLE_CONTENT_CLOUD_PLAY_POPOVER\x10\xc9\x04\x12\x36\n1DISMISSIBLE_CONTENT_CUSTOM_THEMES_NITRO_HOME_TILE\x10\xca\x04\x12?\n:DISMISSIBLE_CONTENT_GUILD_HEADER_BOOST_PROGRESS_BAR_UPSELL\x10\xcb\x04\x12\x38\n3DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_NEW_BADGE\x10\xcc\x04\x12\x45\n@DISMISSIBLE_CONTENT_WIDGETS_USER_SETTINGS_PROFILE_PAGE_NEW_BADGE\x10\xcd\x04\x12=\n8DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_COACHMARK\x10\xcf\x04\x12\x39\n4DISMISSIBLE_CONTENT_CHURN_DISCOUNT_PREMIUM_TAB_BADGE\x10\xd0\x04\x12\x33\n.DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_UPSELL\x10\xd1\x04\x12*\n%DISMISSIBLE_CONTENT_NITRO_DROP_REWARD\x10\xd2\x04\x12H\nCDISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_BADGE\x10\xd3\x04\x12L\nGDISMISSIBLE_CONTENT_SEPTEMBER_2025_MARKETING_MOMENT_NITRO_TAB_COACHMARK\x10\xd4\x04\x12\x35\n0DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_REMINDER\x10\xd5\x04\x12N\nIDISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_ANNOUNCEMENT_MODAL\x10\xd6\x04\x12\x46\nADISMISSIBLE_CONTENT_SEPTEMBER_MARKETING_MOMENT_ANNOUNCEMENT_MODAL\x10\xd7\x04\x12\x38\n3DISMISSIBLE_CONTENT_DO_NOT_DISTURB_REMINDER_POPOVER\x10\xd8\x04\x12\x34\n/DISMISSIBLE_CONTENT_ACCOUNT_LINK_INVITE_FRIENDS\x10\xd9\x04\x12<\n7DISMISSIBLE_CONTENT_POST_ACCOUNT_CONNECTION_RTC_POPOVER\x10\xda\x04\x12J\nEDISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_WEB_BADGE\x10\xdb\x04\x12M\nHDISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_APPEARANCE_SETTINGS_MOBILE_BADGE\x10\xdc\x04\x12\x41\n<DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TRICK_ICON_WEB_BADGE\x10\xdd\x04\x12\x41\n<DISMISSIBLE_CONTENT_HALLOWEEN_APP_ICONS_TREAT_ICON_WEB_BADGE\x10\xde\x04\x12:\n5DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_DM_HOME_BANNER\x10\xdf\x04\x12>\n9DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_CHAT_BOTTOM_BANNER\x10\xe0\x04\x12\x42\n=DISMISSIBLE_CONTENT_NOTIFICATION_NUDGE_APP_START_BOTTOM_SHEET\x10\xe1\x04\x12,\n\'DISMISSIBLE_CONTENT_ACCOUNT_LINK_PROMPT\x10\xe2\x04\x12\x37\n2DISMISSIBLE_CONTENT_WISHLIST_NUX_TOOLTIP_AND_MODAL\x10\xe3\x04\x12\x46\nADISMISSIBLE_CONTENT_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_NEW_BADGE\x10\xe5\x04\x12\x38\n3DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_PORTKEY_TOS\x10\xe6\x04\x12\x42\n=DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_NEW_BADGE\x10\xe7\x04\x12G\nBDISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_LINKED\x10\xe8\x04\x12I\nDDISMISSIBLE_CONTENT_APPLICATION_WIDGET_EDIT_PROFILE_POPOVER_UNLINKED\x10\xe9\x04\x12\x44\n?DISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_CONNECT\x10\xea\x04\x12G\nBDISMISSIBLE_CONTENT_APPLICATION_WIDGET_EMPTY_STATE_CARD_ADD_WIDGET\x10\xeb\x04\x12\x36\n1DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_BADGE\x10\xec\x04\x12\x35\n0DISMISSIBLE_CONTENT_WISHLIST_SHOP_BUTTON_POPOVER\x10\xed\x04\x12\x30\n+DISMISSIBLE_CONTENT_HANG_STATUS_POPOVER_NUX\x10\xee\x04\x12\x39\n4DISMISSIBLE_CONTENT_REPORT_TO_MOD_EXIT_SURVEY_NOTICE\x10\xef\x04\x12\x35\n0DISMISSIBLE_CONTENT_NAGBAR_NOTICE_PASSKEY_BACKUP\x10\xf0\x04\x12<\n7DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_NITRO_HOME_TILE\x10\xf1\x04\x12\x42\n=DISMISSIBLE_CONTENT_CROSS_DM_SEARCH_SETTING_EDUCATION_POPOVER\x10\xf3\x04\x12\x32\n-DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_COUNTDOWN\x10\xf6\x04\x12\x39\n4DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_HALLOWEEN_2025\x10\xf7\x04\x12\x39\n4DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_ONBOARDING\x10\xf8\x04\x12\x45\n@DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_ANNOUNCEMENT_UPSELL\x10\xf9\x04\x12\x37\n2DISMISSIBLE_CONTENT_NITRO_TAB_BADGE_OFFER_REMINDER\x10\xfa\x04\x12@\n;DISMISSIBLE_CONTENT_VIRTUAL_CURRENCY_MOBILE_ONBOARDING_PILL\x10\xfb\x04\x12H\nCDISMISSIBLE_CONTENT_GAME_WIDGETS_USER_PROFILE_ACCOUNT_POPOUT_UPSELL\x10\xfc\x04\x12\x37\n2DISMISSIBLE_CONTENT_RECURRING_3P_PROMOTION_POPOVER\x10\xfd\x04\x12\x41\n<DISMISSIBLE_CONTENT_PREMIUM_TAB_MARKETING_MOMENT_OFFER_BADGE\x10\xfe\x04\x12:\n5DISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_COACHMARK\x10\xff\x04\x12,\n\'DISMISSIBLE_CONTENT_GAME_SHOP_NEW_BADGE\x10\x80\x05\x12.\n)DISMISSIBLE_CONTENT_GAME_SHOP_RTC_POPOVER\x10\x81\x05\x12\x46\nADISMISSIBLE_CONTENT_GUILD_JOINT_PERMISSION_MIGRATION_NOTIFICATION\x10\x82\x05\x12\x35\n0DISMISSIBLE_CONTENT_GAME_SHOP_ANNOUNCEMENT_MODAL\x10\x83\x05\x12\x35\n0DISMISSIBLE_CONTENT_CHECKPOINT_2025_BOTTOM_SHEET\x10\x84\x05\x12\x33\n.DISMISSIBLE_CONTENT_GAME_SHOP_WISHLIST_POPOVER\x10\x85\x05\x12\x34\n/DISMISSIBLE_CONTENT_DISCOUNT_OFFER_ACTION_SHEET\x10\x86\x05\x12@\n;DISMISSIBLE_CONTENT_MOBILE_PREMIUM_TRIAL_OFFER_ACTION_SHEET\x10\x87\x05\x12\x46\nADISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_ANNOUNCEMENT_MODAL\x10\x88\x05\x12=\n8DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_NEW_BADGE\x10\x89\x05\x12\x36\n1DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_WIDE_BANNER\x10\x8a\x05\x12:\n5DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_BETA_COACHMARK\x10\x8b\x05\x12\x43\n>DISMISSIBLE_CONTENT_DISPLAY_NAME_STYLES_MOBILE_PROFILE_TOOLTIP\x10\x8d\x05\x12\x37\n2DISMISSIBLE_CONTENT_CHECKPOINT_2025_DESKTOP_UPSELL\x10\x8e\x05\x12\x41\n<DISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_SUGGESTED_WIDGET\x10\x8f\x05\x12L\nGDISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_LINKED\x10\x90\x05\x12N\nIDISMISSIBLE_CONTENT_APPLICATION_WIDGET_WUWA_EDIT_PROFILE_POPOVER_UNLINKED\x10\x91\x05\x12\x38\n3DISMISSIBLE_CONTENT_INSTALLED_GAME_COMMUNITY_UPSELL\x10\x92\x05\x12\x38\n3DISMISSIBLE_CONTENT_GAME_SHOP_RTC_GIFTING_NEW_BADGE\x10\x93\x05\x12\x38\n3DISMISSIBLE_CONTENT_GAME_INVITE_ACCOUNT_LINK_UPSELL\x10\x94\x05\x12\x38\n3DISMISSIBLE_CONTENT_NITRO_PRIVACY_PERK_NEW_BADGE_V2\x10\x95\x05\x12\x39\n4DISMISSIBLE_CONTENT_GUILD_TAG_AVAILABLE_COACHMARK_V2\x10\x96\x05\x12\x34\n/DISMISSIBLE_CONTENT_GUILD_TAG_UPDATED_COACHMARK\x10\x97\x05\x12-\n(DISMISSIBLE_CONTENT_ORB_RENTAL_NEW_BADGE\x10\x98\x05\x12\x36\n1DISMISSIBLE_CONTENT_HOLIDAY_COACHMARK_WINTER_2025\x10\x99\x05\x12\x44\n?DISMISSIBLE_CONTENT_WISHLIST_USER_PROFILE_ACCOUNT_POPOUT_UPSELL\x10\x9a\x05\x12:\n5DISMISSIBLE_CONTENT_TRIAL_FOR_ALL_2026_SETTINGS_BADGE\x10\x9b\x05\x12.\n)DISMISSIBLE_CONTENT_PREMIUM_GROUP_POPOVER\x10\x9c\x05\x12\x34\n/DISMISSIBLE_CONTENT_PREMIUM_ORBS_UPSELL_POPOVER\x10\x9d\x05\x12:\n5DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_DROP_POPOVER\x10\x9e\x05\x12I\nDDISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_NEW_PERK_AVAILABLE_COACHMARK\x10\xa0\x05\x12;\n6DISMISSIBLE_CONTENT_PREMIUM_ORBS_REWARDS_INTRO_POPOVER\x10\xa1\x05\x12;\n6DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_ADMIN_COACHMARK\x10\xa2\x05\x12<\n7DISMISSIBLE_CONTENT_BOOST_PROGRESS_BAR_MEMBER_COACHMARK\x10\xa3\x05\x12=\n8DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_TAKEOVER_BADGE\x10\xa4\x05\x12<\n7DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_XBOX_ANNOUNCEMENT\x10\xa5\x05\x12\x32\n-DISMISSIBLE_CONTENT_BOOST_TO_UNLOCK_COACHMARK\x10\xa6\x05\x12\x43\n>DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_PRODUCT_CARD_COACHMARK\x10\xa7\x05\x12\x39\n4DISMISSIBLE_CONTENT_WISHLIST_MOBILE_NUX_ACTION_SHEET\x10\xa8\x05\x12=\n8DISMISSIBLE_CONTENT_WISHLIST_MOBILE_YOU_SCREEN_COACHMARK\x10\xa9\x05\x12-\n(DISMISSIBLE_CONTENT_GAME_CLAIM_COACHMARK\x10\xaa\x05\x12\x44\n?DISMISSIBLE_CONTENT_COLLECTIBLES_SHOP_MARVEL_RIVALS_ORBS_REWARD\x10\xab\x05\x12\x33\n.DISMISSIBLE_CONTENT_EXPIRING_POWERUP_COACHMARK\x10\xac\x05\x12-\n(DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL\x10\xad\x05\x12\x34\n/DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_POPOVER_V2\x10\xae\x05\x12\x39\n4DISMISSIBLE_CONTENT_QUEST_HOME_ENTRYPOINT_HERO_BADGE\x10\xaf\x05\x12\x44\n?DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_COACHMARK\x10\xb0\x05\x12\x44\n?DISMISSIBLE_CONTENT_GAME_DETECTION_CREATE_GAME_SERVER_NEW_BADGE\x10\xb1\x05\x12\x34\n/DISMISSIBLE_CONTENT_JOIN_GAME_COMMUNITY_RTC_CTA\x10\xb2\x05\x12\x30\n+DISMISSIBLE_CONTENT_NAGBAR_QUEST_APP_UPSELL\x10\xb3\x05\x12\x35\n0DISMISSIBLE_CONTENT_GAME_SHOP_ORBS_REWARD_BANNER\x10\xb4\x05\x12\x44\n?DISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARDS_ANNOUNCEMENT\x10\xb5\x05\x12:\n5DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_INTRO\x10\xb6\x05\x12>\n9DISMISSIBLE_CONTENT_FAVORITES_SERVER_ONBOARDING_MENU_ITEM\x10\xb7\x05\x12,\n\'DISMISSIBLE_CONTENT_GIFT_INTENT_MESSAGE\x10\xb8\x05\x12H\nCDISMISSIBLE_CONTENT_MOBILE_REFERRAL_PROGRAM_BOTTOM_SHEET_ENTRYPOINT\x10\xb9\x05\x12;\n6DISMISSIBLE_CONTENT_GAME_ACCOUNT_LINK_RECURRING_UPSELL\x10\xba\x05\x12\x39\n4DISMISSIBLE_CONTENT_WISHLIST_MOBILE_VIEWER_COACHMARK\x10\xbb\x05\x12.\n)DISMISSIBLE_CONTENT_EMPTY_GAME_SERVER_TAB\x10\xbc\x05\x12\x43\n>DISMISSIBLE_CONTENT_GUILD_POWERUPS_OVERVIEW_SIDEBAR_VIDEO_CARD\x10\xbd\x05\x12\x46\nADISMISSIBLE_CONTENT_SLAYER_STOREFRONT_ORBS_REWARD_WISHLIST_UPSELL\x10\xbe\x05\x12>\n9DISMISSIBLE_CONTENT_USER_PROFILE_WISHLIST_RECOMMENDATIONS\x10\xbf\x05\x12G\nBDISMISSIBLE_CONTENT_GAME_SERVER_HOSTING_BATCH_RELEASE_V2_COACHMARK\x10\xc0\x05\x12\x34\n/DISMISSIBLE_CONTENT_QUEST_ACTIVITY_HEADER_INTRO\x10\xc1\x05\x12\x44\n?DISMISSIBLE_CONTENT_GAME_SERVER_GAME_DETECTION_UPSELL_NEW_BADGE\x10\xc2\x05\x12\x44\n?DISMISSIBLE_CONTENT_REFERRAL_PROGRAM_ENTRYPOINT_NITRO_TAB_BADGE\x10\xc3\x05\x12<\n7DISMISSIBLE_CONTENT_DOUBLE_TAP_TO_REACT_EXPANDED_UPSELL\x10\xc4\x05\x12\x32\n-DISMISSIBLE_CONTENT_FAVORITES_GUILD_NEW_BADGE\x10\xc5\x05\x12\x36\n1DISMISSIBLE_CONTENT_FIRST_BOOSTER_UPSELL_OVERSEER\x10\xc6\x05\x12\x43\n>DISMISSIBLE_CONTENT_MOBILE_MULTI_GUILD_CREATE_UPSELL_ANIMATION\x10\xc7\x05\x12\x41\n<DISMISSIBLE_CONTENT_PREMIUM_MARKETING_MOMENT_REMINDER_UPSELL\x10\xc8\x05\x12=\n8DISMISSIBLE_CONTENT_GAME_SERVER_PRICING_CHANGE_COACHMARK\x10\xc9\x05\x12\x33\n.DISMISSIBLE_CONTENT_PREMIUM_WISHLIST_COACHMARK\x10\xca\x05\x42\x0c\n\npropertiesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'premium_marketing.v1.PremiumMarketingComponentProperties_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_options = b'8\001'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT'].fields_by_name['colors']._loaded_options = None
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT'].fields_by_name['colors']._serialized_options = b'\020\000'
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES']._serialized_start=105
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES']._serialized_end=38361
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_FEATURECARD']._serialized_start=1870
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_FEATURECARD']._serialized_end=1979
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBSCRIPTIONBUTTON']._serialized_start=1982
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBSCRIPTIONBUTTON']._serialized_end=2126
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBTITLE']._serialized_start=2128
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_SUBTITLE']._serialized_end=2188
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE']._serialized_start=2191
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE']._serialized_end=2958
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_start=2741
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSDARKTHEMEENTRY']._serialized_end=2815
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_start=2817
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTLOCALIZEDVIDEOLINKSLIGHTTHEMEENTRY']._serialized_end=2892
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_start=2894
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_VARIANT1STORAGE_HEROARTVIDEOSUBTITLELINKSENTRY']._serialized_end=2958
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_ANNOUNCEMENTMODALVARIANT1PROPERTIES']._serialized_start=2961
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_ANNOUNCEMENTMODALVARIANT1PROPERTIES']._serialized_end=3734
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTAB']._serialized_start=3736
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTAB']._serialized_end=3803
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNERBUTTON']._serialized_start=3806
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNERBUTTON']._serialized_end=3957
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNER']._serialized_start=3960
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MARKETINGPAGEBANNER']._serialized_end=4187
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PAYMENTMODALBANNER']._serialized_start=4189
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PAYMENTMODALBANNER']._serialized_end=4258
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_CTABUTTON']._serialized_start=4261
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_CTABUTTON']._serialized_end=4396
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MOBILEBOTTOMSHEET']._serialized_start=4399
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_MOBILEBOTTOMSHEET']._serialized_end=4730
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT']._serialized_start=4732
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GRADIENT']._serialized_end=4777
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICON']._serialized_start=4780
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICON']._serialized_end=5003
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_THEMEAWAREASSET']._serialized_start=5005
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_THEMEAWAREASSET']._serialized_end=5110
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICONCOACHMARK']._serialized_start=5113
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTICONCOACHMARK']._serialized_end=5301
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTPLANSELECTIONCARDBANNER']._serialized_start=5304
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTPLANSELECTIONCARDBANNER']._serialized_end=6279
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTCUSTOMIZATIONBANNER']._serialized_start=6282
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTCUSTOMIZATIONBANNER']._serialized_end=6936
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BILLINGSETTINGSNITROGIFTBANNER']._serialized_start=6939
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BILLINGSETTINGSNITROGIFTBANNER']._serialized_end=7477
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERNAGBAR']._serialized_start=7479
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERNAGBAR']._serialized_end=7513
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERCOACHMARK']._serialized_start=7516
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_GIFTREMINDERCOACHMARK']._serialized_end=7708
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTABTOOLTIP']._serialized_start=7711
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_PREMIUMTABTOOLTIP']._serialized_end=7880
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BUTTONACTION']._serialized_start=7883
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_BUTTONACTION']._serialized_end=8174
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_DISMISSIBLECONTENT']._serialized_start=8178
  _globals['_PREMIUMMARKETINGCOMPONENTPROPERTIES_DISMISSIBLECONTENT']._serialized_end=38347
# @@protoc_insertion_point(module_scope)
